Summary:     LDAP suite of applications and development tools
Name:        openldap22
Version:     2.2.19
Release:     8.pp
License:     OpenLDAP
Group:       System Environment/Libraries
Source0:     ftp://ftp.openldap.org/pub/OpenLDAP/openldap-release/openldap-%{version}.tgz
Source1:     ldap.init
Source2:     ldap.sysconfig
Source3:     openldap-redhat-schema.tar.gz
Patch0:      openldap-nostrip.patch
Patch1:      openldap-paths.patch
URL:         http://www.openldap.com/
Buildroot:   /var/tmp/%{name}-root
Vendor:      OpenLDAP Foundation
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Requires:    glibc openssl097 cyrus-sasl2 db4 zlib
Provides:    %{name}.pp
Prereq:      /bin/bash /sbin/ldconfig
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install
BuildPrereq: glibc-devel openssl097-devel cyrus-sasl2-devel db4-devel
BuildPrereq: zlib-devel perl
BuildConflicts: bind-devel
ExclusiveOS: linux

%description
The OpenLDAP Project is a collaborative effort to provide a
robust, commercial-grade, fully featured, open source LDAP
software suite. The project is managed by a worldwide community
of volunteers that use the Internet to communicate, plan, and
develop OpenLDAP Software and its related documentation.
OpenLDAP Software provides a complete LDAP implementation
including server, clients, C SDK, and associated tools.


%package clients
Summary:     Client programs for OpenLDAP
Group:       Applications/Internet
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-clients.pp
Conflicts:   openldap-clients < %{version}

%package devel
Summary:     Development files for OpenLDAP
Group:       Development/Libraries
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-devel.pp
Conflicts:   openldap-devel < %{version}

%package servers
Summary:     OpenLDAP servers and related files
Group:       System Environment/Daemons
Requires:    %{name} = %{version}-%{release} %{name}.pp
Requires:    perl libtool-libs
Provides:    %{name}-utils.pp
Conflicts:   openldap-servers < %{version}


%description clients
The %{name}-clients package contains the client programs needed
for accessing and modifying OpenLDAP directories.

%description devel
The %{name}-devel package contains the header files, libraries
and documentation for building programs using OpenLDAP.

%description servers
The %{name}-servers package contains the slapd and slurpd servers
and related files.


%prep
%setup -q -n openldap-%{version}
%patch0 -p1 -b .strip
%patch1 -p1 -b .paths

# Prepare docs
cp -rf servers/slapd/back-meta/data back-meta
mkdir back-monitor; cp -f servers/slapd/back-monitor/README back-monitor
mkdir back-null; cp -f servers/slapd/back-null/README back-null
mkdir back-perl; cp -f servers/slapd/back-perl/{README,SampleLDAP.pm} back-perl


%build
export CPPFLAGS="$RPM_OPT_FLAGS -I/usr/kerberos/include"
export LDFLAGS="-L/usr/kerberos/lib"
export LIBS="-ldb-4.2"
./configure \
	--prefix=/usr            \
	--sysconfdir=/etc        \
	--localstatedir=/var     \
	--mandir=/usr/share/man  \
	--enable-syslog          \
	--enable-ipv6            \
	--with-cyrus-sasl        \
	--with-threads           \
	--with-tls               \
	--enable-slapd           \
	--enable-aci             \
	--enable-crypt           \
	--enable-lmpasswd        \
	--enable-spasswd         \
	--enable-modules         \
	--enable-rewrite         \
	--enable-rlookups        \
	--enable-slapi           \
	--enable-wrappers        \
	--enable-slurpd          \
	--enable-static          \
	--enable-shared          \
	--enable-bdb=yes         \
	--enable-hdb=mod         \
	--enable-ldbm=mod        \
	--enable-dnssrv=mod      \
	--enable-ldap=mod        \
	--enable-meta=mod        \
	--enable-monitor=mod     \
	--enable-null=mod        \
	--enable-passwd=mod      \
	--enable-perl=mod        \
	--enable-dyngroup=mod    \
	--enable-proxycache=mod
make depend
make


# Do not strip, only compress documentation
%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/sysconfig
mkdir -p $RPM_BUILD_ROOT/usr
mkdir -p $RPM_BUILD_ROOT/var/log/ldap
make \
	DESTDIR=$RPM_BUILD_ROOT \
	install
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/ldap
install -m 0600 %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/ldap
chmod a+x $RPM_BUILD_ROOT/usr/lib/*.so*
tar xzf %{SOURCE3} -C $RPM_BUILD_ROOT/etc/openldap


%pre servers
# Add user and groups if necessary
/usr/sbin/groupadd -g 55 -r ldap 2>/dev/null || :
/usr/sbin/useradd -d /var/lib/ldap -s /bin/false -c "LDAP User" \
	-g ldap -G ldap -M -r -u 55 ldap 2>/dev/null || :


%post
/sbin/ldconfig

%post servers
/sbin/chkconfig --add ldap
/sbin/chkconfig ldap on
if [ -f /var/lock/subsys/ldap ]; then
   /etc/rc.d/init.d/ldap restart
fi


%preun servers
if [ $1 = 0 ] ; then
   /sbin/chkconfig ldap off
   /sbin/chkconfig --del ldap
   if [ -f /var/lock/subsys/ldap ]; then
      /etc/rc.d/init.d/ldap stop
   fi
fi


%postun
/sbin/ldconfig


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc ANNOUNCEMENT CHANGES COPYRIGHT INSTALL LICENSE README
%doc %dir doc/rfc
#%dir /etc/openldap
#%config(noreplace) /etc/openldap/ldap.conf
/etc/openldap/ldap.conf.default
/usr/lib/*.so.*
/usr/share/man/man5/ldap*
#%dir /usr/share/openldap
/usr/share/openldap/*

%files clients
%defattr(-,root,root)
/usr/bin/*
/usr/share/man/man1/*
/usr/share/man/man5/ldif*

%files devel
%defattr(-,root,root)
%doc %dir doc/drafts
/usr/include/*
/usr/lib/*.*a
/usr/lib/*.so
/usr/share/man/man3/*

%files servers
%defattr(-,root,root)
%doc %dir back-meta back-monitor back-null back-perl
%config(noreplace) %attr(640,root,ldap) /etc/openldap/slapd.conf
/etc/openldap/slapd.conf.default
%dir /etc/openldap/schema
%config(noreplace) /etc/openldap/schema/*.schema
/etc/openldap/schema/*.default
/etc/openldap/schema/README
%dir /etc/openldap/schema/redhat
%config(noreplace) /etc/openldap/schema/redhat/*.schema
/etc/rc.d/init.d/ldap
%config(noreplace) /etc/sysconfig/ldap
%dir /usr/libexec/openldap
/usr/libexec/openldap/*
/usr/sbin/*
/usr/share/man/man5/slap*
/usr/share/man/man8/*
%dir %attr(750,ldap,ldap) /var/lib/ldap
%dir %attr(750,ldap,ldap) /var/lib/ldap/replica
%dir %attr(750,ldap,ldap) /var/log/ldap
%dir %attr(750,ldap,ldap) /var/run/ldap


%changelog
* Tue Nov 30 2004 peter.pramberger@member.fsf.org
- new version 2.2.19

* Thu Oct 14 2004 peter.pramberger@member.fsf.org
- new version 2.2.17

* Fri Jul 16 2004 peter.pramberger@member.fsf.org
- new version 2.2.14
- some spec file cleanups

* Mon Apr 19 2004 peter.pramberger@member.fsf.org
- created

